<?xml version="1.0" ?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xpath-default-namespace="http://www.tei-c.org/ns/1.0">
    
    <xsl:output method="xml"
        omit-xml-declaration="yes"
        encoding="UTF-8"
        indent="yes" />
        
    <xsl:template match="/">
        <xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html></xsl:text>
        <html>
            <head>
                <title>
                    <xsl:value-of select="/TEI/teiHeader/fileDesc/titleStmt/title"/>
                </title>
                <link rel="stylesheet" type="text/css" href="css/edition.css" />
                <meta name="author">
                    <xsl:attribute name="content">
                        <xsl:value-of select="//titleStmt/editor"/>
                    </xsl:attribute>
                </meta>
                <meta name="description">
                    <xsl:attribute name="content">
                        <xsl:value-of select="//profileDesc/abstract/p"/>
                    </xsl:attribute>
                </meta>
                <meta name="keywords">
                    <xsl:attribute name="content">
                        <xsl:for-each
                            select="//textClass/keywords/term">
                            <xsl:value-of select="."/>
                            <xsl:if test="position()!=last()">
                                <xsl:text>, </xsl:text>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:attribute>
                </meta>
                <meta charset="UTF-8"/>
            </head>
            <body>
                <header>
                    <h1>
                        <xsl:value-of select="/TEI/teiHeader/fileDesc/titleStmt/title[@type='main']"
                        />
                    </h1>
                    <h2>
                        <xsl:value-of select="/TEI/teiHeader/fileDesc/titleStmt/title[@type='sub']"
                        />
                    </h2>
                </header>
                <nav>
                    <ul>
                        <li>
                            <a href="index.html">Start</a>
                        </li>
                        <li>
                            <a href="edition.html">Edition</a>
                        </li>
                        <li>
                            <a href="about.html">About</a>
                        </li>
                    </ul>
                </nav>
                <section id="content">
                    <h3><xsl:value-of select="//body/head" /></h3>
                    <xsl:apply-templates select="//body/div"/>
                </section>
                <footer>
                    <div>
                        <img src="images/zim.png" height="60" />
                        <img src="images/dixit.png" height="60" />
                        <img src="images/ide.png" height="60" />
                    </div>
                </footer>
            </body>
        </html>
    </xsl:template>
   
    <xsl:template match="head">
        <xsl:element name="h{count(ancestor::div) + 3}">
            <xsl:if test=".[parent::div/@type='poem']">
                <xsl:attribute name="class">
                    <xsl:text>right</xsl:text>
                </xsl:attribute>
            </xsl:if>
            <xsl:apply-templates/>
        </xsl:element>
    </xsl:template>
    
    <xsl:template match="div">
        <div>
            <xsl:attribute name="class" select="@type"></xsl:attribute>
            <xsl:apply-templates/>
        </div>
    </xsl:template>
    
    <xsl:template match="lg">
        <div class="stanza">
            <xsl:apply-templates/>
        </div>
    </xsl:template>
    
    <xsl:template match="l">
        <br/>
        <xsl:apply-templates/>
    </xsl:template>
    
    <xsl:template match="hi">
        <span>
            <xsl:attribute name="class" select="@rend"/>
            <xsl:apply-templates />
        </span>
    </xsl:template>
    
    <xsl:template match="lb">
        <br />
    </xsl:template>
   
    <xsl:template match="pb">    
        <img width="300">
            <xsl:attribute name="src" select="//surface[@xml:id=current()/@facs/substring-after(.,'#')]/graphic[1]/@url"></xsl:attribute>
        </img>
    </xsl:template>
   
</xsl:stylesheet>
